
# Slot: causes adverse event


holds between a drug and a disease or phenotype that can be caused by the drug

URI: [biolink:causes_adverse_event](https://w3id.org/biolink/vocab/causes_adverse_event)


## Domain and Range

[Drug](Drug.md) &#8594;  <sub>0..\*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [causes](causes.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | Aeolus:0000001 |

